--- old/usr/src/cmd/file/file.c	Wed Jul 11 20:34:36 2012
+++ new/usr/src/cmd/file/file.c	Wed Jul 11 20:34:35 2012
@@ -30,6 +30,10 @@
  * Use is subject to license terms.
  */
 
+/*
+ * Copyright 2012, Josef 'Jeff' Sipek <jeffpc@31bits.net>. All rights reserved.
+ */
+
 #define	_LARGEFILE64_SOURCE
 
 /* Get definitions for the relocation types supported. */
@@ -141,6 +145,7 @@
 static int	ifd = -1;
 static int	elffd = -1;
 static int	tret;
+static int	sflg;
 static int	hflg;
 static int	dflg;
 static int	mflg;
@@ -218,7 +223,7 @@
 #endif
 	(void) textdomain(TEXT_DOMAIN);
 
-	while ((ch = getopt(argc, argv, "M:cdf:him:")) != EOF) {
+	while ((ch = getopt(argc, argv, "M:cdsf:him:")) != EOF) {
 		switch (ch) {
 
 		case 'M':
@@ -238,6 +243,10 @@
 			}
 			break;
 
+		case 's':
+			sflg++;
+			break;
+
 		case 'f':
 			fflg++;
 			errno = 0;
@@ -291,6 +300,8 @@
 	if (iflg && cflg) {
 		usage();
 	}
+	if (sflg && (iflg || cflg))
+		usage();
 
 	if (!dflg && !mflg && !M_flg && !iflg) {
 	/* no -d, -m, nor -M option; also -i option doesn't need magic  */
@@ -458,6 +469,8 @@
 		}
 		break;
 	case S_IFCHR:
+		if (sflg)
+			break;
 		(void) printf(gettext("character"));
 		goto spcl;
 
@@ -481,6 +494,8 @@
 		return (0);
 
 	case S_IFBLK:
+		if (sflg)
+			break;
 		(void) printf(gettext("block"));
 					/* major and minor, see sys/mkdev.h */
 spcl:
@@ -1645,8 +1660,8 @@
 usage(void)
 {
 	(void) fprintf(stderr, gettext(
-	    "usage: file [-dh] [-M mfile] [-m mfile] [-f ffile] file ...\n"
-	    "       file [-dh] [-M mfile] [-m mfile] -f ffile\n"
+	    "usage: file [-dhs] [-M mfile] [-m mfile] [-f ffile] file ...\n"
+	    "       file [-dhs] [-M mfile] [-m mfile] -f ffile\n"
 	    "       file -i [-h] [-f ffile] file ...\n"
 	    "       file -i [-h] -f ffile\n"
 	    "       file -c [-d] [-M mfile] [-m mfile]\n"));
--- old/usr/src/man/man1/file.1	Wed Jul 11 20:34:36 2012
+++ new/usr/src/man/man1/file.1	Wed Jul 11 20:34:36 2012
@@ -13,12 +13,12 @@
 .SH SYNOPSIS
 .LP
 .nf
-\fB/usr/bin/file\fR [\fB-dh\fR] [\fB-m\fR \fImfile\fR] [\fB-M\fR \fIMfile\fR] [\fB-f\fR \fIffile\fR] \fIfile\fR...
+\fB/usr/bin/file\fR [\fB-dhs\fR] [\fB-m\fR \fImfile\fR] [\fB-M\fR \fIMfile\fR] [\fB-f\fR \fIffile\fR] \fIfile\fR...
 .fi
 
 .LP
 .nf
-\fB/usr/bin/file\fR [\fB-dh\fR] [\fB-m\fR \fImfile\fR] [\fB-M\fR \fIMfile\fR] \fB-f\fR \fIffile\fR
+\fB/usr/bin/file\fR [\fB-dhs\fR] [\fB-m\fR \fImfile\fR] [\fB-M\fR \fIMfile\fR] \fB-f\fR \fIffile\fR
 .fi
 
 .LP
@@ -38,12 +38,12 @@
 
 .LP
 .nf
-\fB/usr/xpg4/bin/file\fR [\fB-dh\fR] [\fB-m\fR \fImfile\fR] [\fB-M\fR \fIMfile\fR] [\fB-f\fR \fIffile\fR] \fIfile\fR...
+\fB/usr/xpg4/bin/file\fR [\fB-dhs\fR] [\fB-m\fR \fImfile\fR] [\fB-M\fR \fIMfile\fR] [\fB-f\fR \fIffile\fR] \fIfile\fR...
 .fi
 
 .LP
 .nf
-\fB/usr/xpg4/bin/file\fR [\fB-dh\fR] [\fB-m\fR \fImfile\fR] [\fB-M\fR \fIMfile\fR] \fB-f\fR \fIffile\fR
+\fB/usr/xpg4/bin/file\fR [\fB-das\fR] [\fB-m\fR \fImfile\fR] [\fB-M\fR \fIMfile\fR] \fB-f\fR \fIffile\fR
 .fi
 
 .LP
@@ -154,6 +154,16 @@
 of file further, but identifies the file as a "regular file".
 .RE
 
+.sp
+.ne 2
+.na
+\fB\fB-s\fR\fR
+.ad
+.RS 12n
+If a file is a block device or a character device, this option attempts to
+classify the contents of the device as if it were a regular file.
+.RE
+
 .sp
 .ne 2
 .na
